<?xml version="1.0" encoding="ISO-8859-1"?> 

<xsl:stylesheet 
   version="1.0" 
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns="http://www.w3.org/TR/REC-html40"> 

<xsl:output method="text" encoding="ISO-8859-1"/>

<xsl:variable name="imgs" select="count(//img)"/>
<xsl:variable name="init" select="sum(/whs/imgseq/init/@showtime)"/>

<xsl:variable name="actualShowtime" select="(1000*//imgseq/end/@sec + //imgseq/end/@ms - (1000*//imgseq/start/@sec + //imgseq/start/@ms)) - $init"/>

<xsl:variable name="showtime" select="sum(//img/@showtime)"/>
<xsl:variable name="showtimePlanned" select="sum(//img/@showtime_planned)"/>
<xsl:variable name="showtimePlanned2" select="sum(//img/@showtime_planned2)"/>
<xsl:variable name="sleeped" select="sum(//img/@sleep[. > 0])"/>
<xsl:variable name="cpuLag" select="-1 * sum(//img/@sleep[. &lt; 0])"/>
<xsl:variable name="paused" select="sum(//img/@paused)"/>
<xsl:variable name="pausedCounter" select="count(//img/@paused[. > 0])"/>
<xsl:variable name="nextpicCounter" select="count(//img/@nextPic[. > 0])"/>


<xsl:variable name="basedir" select="whs/imgseq/@basedir"/>
<xsl:variable name="fps" select="30"/>
<xsl:variable name="mspf" select="round(1000 div $fps)"/><!-- milliseconds per frame -->


<!--
-->
<xsl:template name="getShowTime">
   <xsl:param name="image" />
   
   <xsl:value-of select="@showtime"/>
</xsl:template>          

<xsl:template name="frames">
   <xsl:param name="time" />

   <xsl:variable name="showtime">
     <xsl:call-template name="getShowTime">
       <xsl:with-param name="image" select='.' />
     </xsl:call-template>   
   </xsl:variable>

   <xsl:value-of select="$showtime * $fps div 1000"/>
</xsl:template>          



<xsl:template match="imgseq">

fname_path = "<xsl:value-of select="$basedir"/>\"
global use_devil=false
global fps=<xsl:value-of select="$fps"/>
# <xsl:value-of select="$fps"/> fps -> <xsl:value-of select="$mspf"/> ms per frame
# good delay-values (in ms): <xsl:value-of select="$mspf"/>, <xsl:value-of select="$mspf*2"/>, <xsl:value-of select="$mspf*3"/>, <xsl:value-of select="$mspf*4"/>, <xsl:value-of select="$mspf*5"/>, <xsl:value-of select="$mspf*6"/>, <xsl:value-of select="$mspf*7"/>, <xsl:value-of select="$mspf*8"/>, <xsl:value-of select="$mspf*9"/>, <xsl:value-of select="$mspf*10"/>
#

Function addImg( clip c, string path, int framescount ) {
    return c + ((framescount>1) ? ImageReader(path, 0, 0, fps, use_devil).Loop(framescount) : ImageReader(path, 0, 0, fps, use_devil))
}

Function addImg( clip c, string path ) {    
    return c + ImageReader(path, 0, 0, fps, use_devil)
}


#ImageReader(string "path", int "begin", int "end", int "fps", bool "use_DevIL")
<xsl:for-each select="/whs/imgseq/img[position() = 1]">
  <xsl:variable name="numOfFrames"><xsl:call-template name="frames"><xsl:with-param name="image" select='.'/></xsl:call-template></xsl:variable>
  <xsl:variable name="showTime"><xsl:call-template name="getShowTime"><xsl:with-param name="image" select='.'/></xsl:call-template></xsl:variable>
ImageReader( fname_path + "<xsl:value-of select="@file"/>", 0, 0, fps, use_devil).Loop( <xsl:value-of select="round( $numOfFrames )"/> )  # <xsl:value-of select="$numOfFrames"/> frames, <xsl:value-of select="$showTime"/> ms

</xsl:for-each>


<!--
<xsl:for-each select = "//img[position() > 1]">
-->
<xsl:for-each select="/whs/imgseq/img[position() > 1]">
  <xsl:variable name="numOfFrames"><xsl:call-template name="frames"><xsl:with-param name="image" select='.'/></xsl:call-template></xsl:variable>
  <xsl:variable name="showTime"><xsl:call-template name="getShowTime"><xsl:with-param name="image" select='.'/></xsl:call-template></xsl:variable
  >addImg( fname_path + "<xsl:value-of select="@file"/>", <xsl:value-of select="round( $numOfFrames )"/> )  # <xsl:value-of select="$numOfFrames"/> frames, <xsl:value-of select="$showTime"/> ms
</xsl:for-each>

# Calculated duration: <xsl:value-of select="$showtime"/>

<!--
-->
FlipVertical()

# for testing
ShowFrameNumber(true) #(clip, bool "scroll")
#ReduceBy2()

        
# This document was translated by a XSLT-Processor from <xsl:value-of select="system-property('xsl:vendor')"/> (version <xsl:value-of select="system-property('xsl:version')"/>) - <xsl:value-of select="system-property('xsl:vendor-url')"/>    
</xsl:template>




</xsl:stylesheet>